@@ -394,3 +394,9 @@ class Sample:
         io.write(self.png)
         io.seek(0) # rewind to start of file
         return Image.open(io)
+
+    def get_context_image(self):
+        io = BytesIO()
+        io.write(self.context_png)
+        io.seek(0) # rewind to start of file
+        return Image.open(io)
